import xbmc
import xbmcvfs
import xbmcgui
import xbmcaddon
import xbmcplugin
import sys
import json
import requests
from pathlib import Path
from urllib.parse import quote_plus, unquote_plus
from bs4 import BeautifulSoup as bs
import sqlite3

class Myaddon:
	
	addon_id = xbmcaddon.Addon().getAddonInfo('id')
	addon_name = xbmcaddon.Addon().getAddonInfo('name')
	addon_data = Path(xbmcvfs.translatePath(xbmcaddon.Addon().getAddonInfo('profile')))
	downloads_path = addon_data / 'downloads'
	cache_file = addon_data / 'cache.db'
	addon_path = Path(xbmcvfs.translatePath(xbmcaddon.Addon().getAddonInfo('path')))
	addon_icon = xbmcaddon.Addon().getAddonInfo('icon')
	addon_fanart = xbmcaddon.Addon().getAddonInfo('fanart')
	addon_version = xbmcaddon.Addon().getAddonInfo('version')
	get_setting = xbmcaddon.Addon().getSetting
	set_setting = xbmcaddon.Addon().setSetting
	api_key = 'f090bb54758cabf231fb605d3e3e0468'
	user_agent = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/89.0.4389.90 Safari/537.36'
	headers = {"User-Agent":user_agent, "Connection":'keep-alive', 'Accept':'audio/webm,audio/ogg,udio/wav,audio/*;q=0.9,application/ogg;q=0.7,video/*;q=0.6,*/*;q=0.5'}
	
	#---Log---#
	
	def log(self, message, error = ''):
		return xbmc.log(f'{message} {error}', xbmc.LOGINFO)
	
	#---Request and Other Various Methods---#
	
	def get_page(self, page):
		if page is None:
			return None
		if page.startswith('http'):
			return requests.get(page, headers=Myaddon.headers).text
		return None
	
	def write_to_file(self, _file, _string):
		with open(_file, 'w', encoding='utf-8') as f:
			f.write(_string)

	def get_json(self, page):
		return json.loads(self.get_page(page))
	
	def write_json(self, file_path, items):
		with open(file_path, 'w', encoding='utf-8') as f:
			json.dump({'items': items}, f, indent = 4)
	
	def get_soup(self, url):
		if url is None:
			return None
		if url.startswith('http'):
			return bs(self.get_page(url), 'html.parser')
		return None
	
	def write_soup(self, file_path, url):
		with open(file_path, 'w', encoding='utf-8') as f:
			f.write(self.get_soup(url).prettify())

	#---Add Directory Method---#

	def add_dir(self, name, url, mode, icon, fanart, description, page='', foldername='', contextMenu=None, infolabels=None, media_type='movie', cast=None, videos_url='',_id='', season_number='', episode_number='', isFolder=True):
		u=sys.argv[0]+'?name='+quote_plus(name)+'&url='+quote_plus(url)+'&mode='+str(mode)+'&icon='+quote_plus(icon) +'&fanart='+quote_plus(fanart)+'&description='+quote_plus(description)+'&page='+str(page)+'&foldername='+quote_plus(foldername)+'&videos_url='+quote_plus(videos_url)+'&media_type='+quote_plus(media_type)+'&_id='+str(_id)+'&season_number='+str(season_number)+'&episode_number='+str(episode_number)
		liz=xbmcgui.ListItem(name)
		liz.setArt({'fanart': fanart, 'icon': icon, 'thumb': icon, 'poster': icon})
		if infolabels is not None:
			liz.setInfo(type='video', infoLabels=infolabels)
		else:
			liz.setInfo(type='video', infoLabels={'mediatype': media_type, 'title': name, 'plot': description})
		if _id != '':
			liz.setUniqueIDs({'tmdb' : _id}, "tmdb")
		if cast is not None:
			liz.setCast(cast)
		if contextMenu is not None:
			liz.addContextMenuItems(contextMenu)
		xbmcplugin.addDirectoryItem(handle=int(sys.argv[1]), url=u,listitem=liz, isFolder=isFolder)
	
	def append_links(self, lists1, lists2):
		for _list in lists2:
			lists1.append(_list)
		return lists1
	
	def get_multilink(self, lists, lists2=None, trailers=None):
		names = []
		links = []
		counter = 1
		if lists is not None:
			if lists2 is not None:
				for _list in lists2:
					lists.append(_list)
			for name, link in lists:
				names.append(f'Link {str(counter)}: {name}')
				links.append(link)
				counter += 1
		if trailers is not None:
			for name, link in trailers:
				names.append(name)
				links.append(link)
		if len(links) > 1:
			dialog = xbmcgui.Dialog()
			ret = dialog.select('Choose a Link', names)
			if ret > -1:
				return links[ret]
			else:
				return None
		elif len(links) == 1:
			return links[0]
		else:
			return None
	
	def from_keyboard(self, default_text='', header='Search'):
		kb = xbmc.Keyboard(default_text, header, False)
		kb.doModal()
		if (kb.isConfirmed()):
			return kb.getText()
		else:
			return None
	
	def dialog_ok(self, message):
		return xbmcgui.Dialog().ok(self.addon_name, message)
	
	#---Video Player---#

	def play_video(self, name, url, icon, description,resolve=False):
	  	 if url is None:
	  	 	return
	  	 url = unquote_plus(url)
	  	 liz = xbmcgui.ListItem(name)
	  	 liz.setInfo('video', {'title': name, 'plot':description})
	  	 liz.setArt({'thumb': icon, 'icon': icon})
	  	 if resolve is True:
	  	 	import resolveurl
	  	 	if resolveurl.HostedMediaFile(url).valid_url():
	  	 		url = resolveurl.HostedMediaFile(url).resolve()
	  	 xbmc.Player().play(url, liz)

	def create_table(self, filename, table_name, items: tuple):
		try:
			db_connect = sqlite3.connect(filename)
			table = f'CREATE TABLE {table_name} {items};'
			cursor = db_connect.cursor()
			self.log('Successfully Connected to SQLite.')
			cursor.execute(table)
			db_connect.commit()
			self.log('SQLite table created.')
		except sqlite3.Error as e:
			self.log('Error while creating a sqlite table: ', e)
		finally:
		   	if db_connect:
		   		db_connect.close()
		   		self.log('SQLite connection is closed.')

	def insert_into_db(self, filename, table_name, columns: tuple, values: tuple):
	   try:
	   	db_connect = sqlite3.connect(filename)
	   	cursor = db_connect.cursor()
	   	self.log('Successfully Connected to SQLite.')
	   	sqlite_insert_query = f'INSERT INTO {table_name} {columns} VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)'
	   	cursor.execute(sqlite_insert_query, values)
	   	db_connect.commit()
	   	self.log(f'Record inserted successfully into {table_name} table.')
	   	cursor.close()
	   except sqlite3.Error as e:
	   	self.log('Failed to insert data into sqlite table: ', e)
	   finally:
	       if db_connect:
	       	db_connect.close()
	       	self.log('The SQLite connection is closed')

	def read_table(self, filename, table):
	   try:
	       sqliteConnection = sqlite3.connect(filename)
	       cursor = sqliteConnection.cursor()
	       #self.log('Connected to SQLite')
	       sqlite_select_query = f'SELECT * from {table}'
	       cursor.execute(sqlite_select_query)
	       record = cursor.fetchall()
	       #self.log("Total rows are:  ", len(record))
	       cursor.close()
	   
	   except sqlite3.Error as e:
	   	self.log('Failed to read data from sqlite table: ', e)
	   finally:
	       if sqliteConnection:
	           sqliteConnection.close()
	           #self.log('The SQLite connection is closed.')
	   return record

	def search_db(self, _id):
		for x in self.read_table(self.cache_file, 'video_metadata'):
			if _id in x:
				return x
		return False